=============
vmware-nsxlib
=============

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/vmware-nsxlib
* Source: http://git.openstack.org/cgit/openstack/vmware-nsxlib
* Bugs: http://bugs.launchpad.net/replace with the name of the project on launchpad

Features
--------

* TODO
